/**
 * @brief ESP32 programming
 * @author Michael Burmeister
 * @date April 15, 2024
 * @version 1.0
 */

#include <stdio.h>
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "nvs_flash.h"
#include "esp_netif.h"
#include "esp_log.h"


#include "status.h"

static const char *TAG = "main";


void delay(int d)
{
    vTaskDelay(d / portTICK_PERIOD_MS);
}

esp_err_t initNVS()
{
    esp_err_t e;

    e = nvs_flash_init();
    if (e == ESP_ERR_NVS_NO_FREE_PAGES || e == ESP_ERR_NVS_NEW_VERSION_FOUND)
    {
        nvs_flash_erase();
        e = nvs_flash_init();
    }
    return e;
}

void app_main(void)
{
    initNVS();

    ESP_LOGI(TAG, "Status");

    status();

    wifi_init_softap();

    wifi_init_sta();

    start();
    
    ESP_LOGI(TAG, "Done");
    while (true)
    {
        delay(1000);
    }

}
